@@ -17,10 +17,10 @@ baseDir = Path(__file__).resolve().parents[0]
 out_dir = None
 # folder name to store output in.
 out_wrapper = "BESOS_Output"
-# where to move output files from failed runs
-err_dir = Path(os.getcwd())
 # folder name to store errors in.
 error_wrapper = "BESOS_Errors"
+# where to move output files from failed runs
+err_dir = Path(os.getcwd(), error_wrapper)
 # where to look for input files
 data_dir = Path(baseDir, "data")
 # whether to use 'idf' or 'json' format by default
@@ -64,6 +64,14 @@ elif energy_plus_mode == "json":
 else:
     raise ModeError(energy_plus_mode)
 
+# TODO: solver_settings came from the config.yaml file that was removed, could be cleaned up
+solver_settings = {
+    "input_file": "data/example_xlsx.xlsx",
+    "output_file": "test.xlsx",
+    "solver": {"name": "glpk", "options": {"mipgap": 0.05}},
+    "BIG_M": 99999,
+}
+
 # the default min and max values for range_parameters
 range_parameter = dict(min=0, max=float("inf"))
 
