@@ -454,9 +454,9 @@ def test_epw_file_rename(building):
     """Verify that calls that use epw_file still work, but produce a warning."""
     with pytest.warns(FutureWarning, match="epw_file has been deprecated"):
         evaluator = EvaluatorEP(
-            problem=Problem(), building=building, epw_file="test/path"
+            problem=Problem(), building=building, epw_file=config.files["epw"]
         )
-    assert evaluator.epw == "test/path"
+    assert evaluator.epw == config.files["epw"]
 
 
 @pytest.mark.compatibility
