@@ -19,6 +19,13 @@ from besos.problem import Problem
 
 # init, setup_checks, and setup_changes were moved directly from Will's code in
 # parameters.py
+
+
+@pytest.fixture(params=["idf", "json"])
+def building(request):
+    return ef.get_building(mode=request.param)
+
+
 def test_init():
     # inputs should be initialisable
     Parameter(
@@ -199,3 +206,39 @@ def test_parameter_name_does_not_overwrite(range_zero_to_five):
         in record.pop(DeprecationWarning).message.args[0]
     )
     assert range_zero_to_five.name == old_name
+
+
+def test_abstractfield_arithmetic(building):
+    mode = ef.get_mode(building)
+    if mode == "idf":
+        index = None
+        for obj in building.idfobjects[
+            "MATERIAL"
+        ]:  # for loop to find index of "Mass NonRes Wall Insulation"
+            if obj.Name == "Mass NonRes Wall Insulation":
+                index = building.idfobjects["MATERIAL"].index(obj)
+                break
+        start = float(
+            building.idfobjects["MATERIAL"][index].Thickness
+        )  # chose arbitrarly as it has thickness values to work with
+        testSelector = FieldSelector(
+            class_name="MATERIAL",
+            object_name="Mass NonRes Wall Insulation",
+            field_name="Thickness",
+        )
+        testSelector.multiply(building, 2)
+        testSelector.add(building, -0.03)  # arbitrary numbers to check for arithmetic
+        end = building.idfobjects["MATERIAL"][index].Thickness
+    else:
+        start = building["Material"]["Mass NonRes Wall Insulation"][
+            "thickness"
+        ]  # chose arbitrarly as it has thickness values to work with
+        testSelector = FieldSelector(
+            class_name="Material",
+            object_name="Mass NonRes Wall Insulation",
+            field_name="thickness",
+        )
+        testSelector.multiply(building, 2)
+        testSelector.add(building, -0.03)
+        end = building["Material"]["Mass NonRes Wall Insulation"]["thickness"]
+    assert (start * 2) - 0.03 == end
